@@ -255,10 +255,11 @@ def check_dimensions(dico):
     """
     supported = (np.ndarray, pd.DataFrame)  # Data types that have a shape attribute
     shapes = [dico[lab].shape for lab in dico
-              if isinstance(dico[lab], supported) and lab.split('.')[0] != 'timestamps']
+              if isinstance(dico[lab], supported) and not lab.startswith('timestamps')]
     first_shapes = [sh[0] for sh in shapes]
     # Continuous timeseries are permitted to be a (2, 2)
-    timeseries = [k for k, v in dico.items() if 'timestamps' in k and isinstance(v, np.ndarray)]
+    timeseries = [k for k, v in dico.items()
+                  if k.startswith('timestamps') and isinstance(v, np.ndarray)]
     if any(timeseries):
         for key in timeseries:
             if dico[key].ndim == 1 or (dico[key].ndim == 2 and dico[key].shape[1] == 1):
@@ -364,17 +365,17 @@ def _ls(alfpath, object=None, **kwargs) -> (list, tuple):
 
 def iter_sessions(root_dir):
     """
-    Recursively iterate over session paths in a given directory
+    Recursively iterate over session paths in a given directory.
 
     Parameters
     ----------
     root_dir : str, pathlib.Path
-        The folder to look for sessions
+        The folder to look for sessions.
 
     Yields
     -------
     pathlib.Path
-        The next session path in lexicographical order
+        The next session path in lexicographical order.
     """
     if spec.is_session_path(root_dir):
         yield root_dir
@@ -383,6 +384,25 @@ def iter_sessions(root_dir):
             yield path
 
 
+def iter_datasets(session_path):
+    """
+    Iterate over all files in a session, and yield relative dataset paths.
+
+    Parameters
+    ----------
+    session_path : str, pathlib.Path
+        The folder to look for datasets.
+
+    Yields
+    -------
+    pathlib.Path
+        The next dataset path (relative to the session path) in lexicographical order.
+    """
+    for p in sorted(Path(session_path).rglob('*.*')):
+        if not p.is_dir() and spec.is_valid(p.name):
+            yield p.relative_to(session_path)
+
+
 def exists(alfpath, object, attributes=None, **kwargs) -> bool:
     """
     Test if ALF object and optionally specific attributes exist in the given path
